@@ -63,8 +63,9 @@
 #include <QtGui/qaccessibleobject.h>
 
 namespace QtWebEngineCore {
-class WebContentsAdapter;
+class RenderWidgetHostViewQtDelegateQuick;
 class UIDelegatesManager;
+class WebContentsAdapter;
 }
 
 QT_BEGIN_NAMESPACE
@@ -74,10 +75,11 @@ class QQmlContext;
 class QQuickWebEngineContextMenuRequest;
 class QQuickWebEngineSettings;
 class QQuickWebEngineFaviconProvider;
+class QQuickWebEngineProfilePrivate;
 
 QQuickWebEngineView::WebAction editorActionForKeyEvent(QKeyEvent* event);
 
-#ifdef ENABLE_QML_TESTSUPPORT_API
+#if QT_CONFIG(webengine_testsupport)
 class QQuickWebEngineTestSupport;
 #endif
 
@@ -88,7 +90,8 @@ public:
     QQuickWebEngineView *q_ptr;
     QQuickWebEngineViewPrivate();
     ~QQuickWebEngineViewPrivate();
-
+    void destroy();
+    void initializeProfile();
     QtWebEngineCore::UIDelegatesManager *ui();
 
     QtWebEngineCore::RenderWidgetHostViewQtDelegate* CreateRenderWidgetHostViewQtDelegate(QtWebEngineCore::RenderWidgetHostViewQtDelegateClient *client) override;
@@ -137,41 +140,54 @@ public:
     QObject *accessibilityParentObject() override;
     QtWebEngineCore::WebEngineSettings *webEngineSettings() const override;
     void allowCertificateError(const QSharedPointer<CertificateErrorController> &errorController) override;
+    void selectClientCert(const QSharedPointer<ClientCertSelectController> &selectController) override;
     void runGeolocationPermissionRequest(QUrl const&) override;
     void renderProcessTerminated(RenderProcessTerminationStatus terminationStatus, int exitCode) override;
     void requestGeometryChange(const QRect &geometry, const QRect &frameGeometry) override;
     void updateScrollPosition(const QPointF &position) override;
     void updateContentsSize(const QSizeF &size) override;
+    void updateNavigationActions() override;
     void startDragging(const content::DropData &dropData, Qt::DropActions allowedActions,
                        const QPixmap &pixmap, const QPoint &offset) override;
+    bool supportsDragging() const override;
     bool isEnabled() const override;
     void setToolTip(const QString &toolTipText) override;
     const QObject *holdingQObject() const override;
+    ClientType clientType() override { return QtWebEngineCore::WebContentsAdapterClient::QmlClient; }
 
-    QSharedPointer<QtWebEngineCore::BrowserContextAdapter> browserContextAdapter() override;
+    QtWebEngineCore::ProfileAdapter *profileAdapter() override;
     QtWebEngineCore::WebContentsAdapter *webContentsAdapter() override;
+    void printRequested() override;
+    void widgetChanged(QtWebEngineCore::RenderWidgetHostViewQtDelegate *newWidgetBase) override;
 
+    void updateAction(QQuickWebEngineView::WebAction) const;
     void adoptWebContents(QtWebEngineCore::WebContentsAdapter *webContents);
     void setProfile(QQuickWebEngineProfile *profile);
+    void updateAdapter();
     void ensureContentsAdapter();
     void setFullScreenMode(bool);
 
+    static void bindViewAndWidget(QQuickWebEngineView *view, QtWebEngineCore::RenderWidgetHostViewQtDelegateQuick *widget);
+    void widgetChanged(QtWebEngineCore::RenderWidgetHostViewQtDelegateQuick *oldWidget,
+                       QtWebEngineCore::RenderWidgetHostViewQtDelegateQuick *newWidget);
+
     // QQmlListPropertyHelpers
     static void userScripts_append(QQmlListProperty<QQuickWebEngineScript> *p, QQuickWebEngineScript *script);
     static int userScripts_count(QQmlListProperty<QQuickWebEngineScript> *p);
     static QQuickWebEngineScript *userScripts_at(QQmlListProperty<QQuickWebEngineScript> *p, int idx);
     static void userScripts_clear(QQmlListProperty<QQuickWebEngineScript> *p);
 
+    QQuickWebEngineProfile *m_profile;
     QSharedPointer<QtWebEngineCore::WebContentsAdapter> adapter;
     QScopedPointer<QQuickWebEngineHistory> m_history;
-    QQuickWebEngineProfile *m_profile;
     QScopedPointer<QQuickWebEngineSettings> m_settings;
-#ifdef ENABLE_QML_TESTSUPPORT_API
+#if QT_CONFIG(webengine_testsupport)
     QQuickWebEngineTestSupport *m_testSupport;
 #endif
     QQmlComponent *contextMenuExtraItems;
     QtWebEngineCore::WebEngineContextMenuData m_contextMenuData;
-    QUrl explicitUrl;
+    QUrl m_url;
+    QString m_html;
     QUrl iconUrl;
     QQuickWebEngineFaviconProvider *faviconProvider;
     int loadProgress;
@@ -187,14 +203,19 @@ public:
     QPointer<QQuickWebEngineView> devToolsView;
     uint m_webChannelWorld;
     bool m_isBeingAdopted;
+    mutable QQuickWebEngineAction *actions[QQuickWebEngineView::WebActionCount];
+    QtWebEngineCore::RenderWidgetHostViewQtDelegateQuick *widget = nullptr;
+
+    bool profileInitialized() const;
 
 private:
     QScopedPointer<QtWebEngineCore::UIDelegatesManager> m_uIDelegatesManager;
     QList<QQuickWebEngineScript *> m_userScripts;
     qreal m_dpiScale;
     QColor m_backgroundColor;
-    qreal m_defaultZoomFactor;
+    qreal m_zoomFactor;
     bool m_ui2Enabled;
+    bool m_profileInitialized;
 };
 
 #ifndef QT_NO_ACCESSIBILITY
